summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneyaccounttreebase.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/widgets/kmymoneyaccounttreebase.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/widgets/kmymoneyaccounttreebase.h')
-rw-r--r--kmymoney2/widgets/kmymoneyaccounttreebase.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/kmymoney2/widgets/kmymoneyaccounttreebase.h b/kmymoney2/widgets/kmymoneyaccounttreebase.h
index 3bd9e91..9843b9d 100644
--- a/kmymoney2/widgets/kmymoneyaccounttreebase.h
+++ b/kmymoney2/widgets/kmymoneyaccounttreebase.h
@@ -47,7 +47,7 @@ class KMyMoneyAccountTreeBase : public KListView
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyAccountTreeBase(TQWidget* tqparent = 0, const char *name = 0);
+ KMyMoneyAccountTreeBase(TQWidget* parent = 0, const char *name = 0);
virtual ~KMyMoneyAccountTreeBase();
/**
@@ -98,9 +98,9 @@ protected:
* account @p accTo.
*
* @param accFrom source account
* @param accTo new tqparent account for @p accFrom
* @retval true drop is ok
* @retval false drop is not ok (@p accTo cannot be tqparent of @p accFrom)
*/
bool dropAccountOnAccount(const MyMoneyAccount& accFrom, const MyMoneyAccount& accTo) const;
// virtual void contentsDropEvent(TQDropEvent*);
@@ -137,7 +137,7 @@ protected:
void queueSort(void);
protected slots:
- void slotObjectDropped(TQDropEvent* event, TQListViewItem* tqparent, TQListViewItem* after);
+ void slotObjectDropped(TQDropEvent* event, TQListViewItem* parent, TQListViewItem* after);
/**
* Select the object pointed to by @p i. This slot emits selectObject signals
@@ -238,12 +238,12 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
* account @p acc to be a subordinate account of @p tqparent.
*
* @param acc const reference to account to be reparented
* @param tqparent const reference to new tqparent account
*/
- void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& tqparent);
+ void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& parent);
/**
* This signal is emitted, when the user selected to reparent the
@@ -267,18 +267,18 @@ public:
* Constructor to be used to construct an institution entry
* object.
*
* @param tqparent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
* the KListView entry is constructed
*/
- KMyMoneyAccountTreeBaseItem(KListView *tqparent, const MyMoneyInstitution& institution);
+ KMyMoneyAccountTreeBaseItem(KListView *parent, const MyMoneyInstitution& institution);
/**
* Constructor to be used to construct a standard account entry object (e.g. Asset,
* Liability, etc.).
*
* @param tqparent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -287,13 +287,13 @@ public:
* @param name name of the account to be used instead of the one stored with @p account
* If empty, the one stored with @p account will be used. Default: empty
*/
- KMyMoneyAccountTreeBaseItem(KListView *tqparent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
+ KMyMoneyAccountTreeBaseItem(KListView *parent, const MyMoneyAccount& account, const MyMoneySecurity& security = MyMoneySecurity(), const TQString& name = TQString());
/**
* Constructor to be used to construct an account entry
* object.
*
* @param tqparent pointer to the tqparent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
* the KListView entry is constructed
@@ -302,7 +302,7 @@ public:
* @param security const reference to the security used to show the value. Usually
* one should pass MyMoneyFile::baseCurrency() here.
*/
- KMyMoneyAccountTreeBaseItem(KMyMoneyAccountTreeBaseItem *tqparent, const MyMoneyAccount& account, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity());
+ KMyMoneyAccountTreeBaseItem(KMyMoneyAccountTreeBaseItem *parent, const MyMoneyAccount& account, const TQValueList<MyMoneyPrice>& price = TQValueList<MyMoneyPrice>(), const MyMoneySecurity& security = MyMoneySecurity());
~KMyMoneyAccountTreeBaseItem();
@@ -411,7 +411,7 @@ public:
* by @p item.
*
* @param item pointer to other KMyMoneyAccountTreeItem that
* should be checked for tqparent/grand-parenthood of this
* object
* @retval true @p this object is a decendant of @p item
* @retval false @p this object is no decendant of @p item
@@ -447,7 +447,7 @@ protected:
* Computes and returns the current value of the account held by this item.
* This is the same as balance() but in the currency of the view.
* if value() changed since the item has been displayed, updateAccount()
* will notify the tqparent.
* @return value of the account held by this item
*/
MyMoneyMoney value() const;
@@ -98,9 +98,9 @@ protected:
*
* @param accFrom source account
- * @param accTo new tqparent account for @p accFrom
+ * @param accTo new parent account for @p accFrom
* @retval true drop is ok
@@ -98,9 +98,9 @@ protected:
* @retval true drop is ok
- * @retval false drop is not ok (@p accTo cannot be tqparent of @p accFrom)
+ * @retval false drop is not ok (@p accTo cannot be parent of @p accFrom)
*/
bool dropAccountOnAccount(const MyMoneyAccount& accFrom, const MyMoneyAccount& accTo) const;
@@ -238,12 +238,12 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
- * account @p acc to be a subordinate account of @p tqparent.
+ * account @p acc to be a subordinate account of @p parent.
*
* @param acc const reference to account to be reparented
@@ -238,12 +238,12 @@ signals:
*
* @param acc const reference to account to be reparented
- * @param tqparent const reference to new tqparent account
+ * @param parent const reference to new parent account
*/
@@ -267,18 +267,18 @@ public:
* object.
*
- * @param tqparent pointer to the KListView object this entry should be
+ * @param parent pointer to the KListView object this entry should be
* added to.
* @param institution const reference to MyMoneyInstitution for which
@@ -267,18 +267,18 @@ public:
* Liability, etc.).
*
- * @param tqparent pointer to the KListView object this entry should be
+ * @param parent pointer to the KListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -287,13 +287,13 @@ public:
* object.
*
- * @param tqparent pointer to the tqparent KAccountListView object this entry should be
+ * @param parent pointer to the parent KAccountListView object this entry should be
* added to.
* @param account const reference to MyMoneyAccount for which
@@ -411,7 +411,7 @@ public:
*
* @param item pointer to other KMyMoneyAccountTreeItem that
- * should be checked for tqparent/grand-parenthood of this
+ * should be checked for parent/grand-parenthood of this
* object
* @retval true @p this object is a decendant of @p item
@@ -447,7 +447,7 @@ protected:
* This is the same as balance() but in the currency of the view.
* if value() changed since the item has been displayed, updateAccount()
- * will notify the tqparent.
+ * will notify the parent.
* @return value of the account held by this item
*/